@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2014-2019 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #include "chatwidget.h"
@@ -97,6 +97,7 @@ ChatMessage::SystemMessageType getChatMessageType(const SystemMessage& systemMes
     case SystemMessageType::fileSendFailed:
     case SystemMessageType::messageSendFailed:
     case SystemMessageType::unexpectedCallEnd:
+    case SystemMessageType::userWentOffline:
         return ChatMessage::ERROR;
     case SystemMessageType::userJoinedConference:
     case SystemMessageType::userLeftConference:
@@ -158,14 +159,14 @@ void forEachLineIn(ChatLine::Ptr first, ChatLine::Ptr last, ChatLineStorage& sto
 ChatLogIdx clampedAdd(ChatLogIdx idx, int val, IChatLog& chatLog)
 {
     if (val < 0) {
-        auto distToEnd = idx - chatLog.getFirstIdx();
+        const auto distToEnd = idx - chatLog.getFirstIdx();
         if (static_cast<size_t>(std::abs(val)) > distToEnd) {
             return chatLog.getFirstIdx();
         }
 
         return idx - std::abs(val);
     }
-    auto distToEnd = chatLog.getNextIdx() - idx;
+    const auto distToEnd = chatLog.getNextIdx() - idx;
     if (static_cast<size_t>(val) > distToEnd) {
         return chatLog.getNextIdx();
     }
@@ -176,13 +177,14 @@ ChatLogIdx clampedAdd(ChatLogIdx idx, int val, IChatLog& chatLog)
 } // namespace
 
 
-ChatWidget::ChatWidget(IChatLog& chatLog_, const Core& core_, DocumentCache& documentCache_,
-                       SmileyPack& smileyPack_, Settings& settings_, Style& style_,
-                       IMessageBoxManager& messageBoxManager_, QWidget* parent)
+ChatWidget::ChatWidget(IChatLog& chatLog_, const ICoreIdHandler& idHandler_, CoreFile* coreFile_,
+                       DocumentCache& documentCache_, SmileyPack& smileyPack_, Settings& settings_,
+                       Style& style_, IMessageBoxManager& messageBoxManager_, QWidget* parent)
     : QGraphicsView(parent)
     , selectionRectColor{style_.getColor(Style::ColorPalette::SelectText)}
     , chatLog(chatLog_)
-    , core(core_)
+    , idHandler(idHandler_)
+    , coreFile(coreFile_)
     , chatLineStorage(new ChatLineStorage())
     , documentCache(documentCache_)
     , smileyPack{smileyPack_}
@@ -269,6 +271,7 @@ ChatWidget::ChatWidget(IChatLog& chatLog_, const Core& core_, DocumentCache& doc
     connect(this, &ChatWidget::renderFinished, this, &ChatWidget::onRenderFinished);
     connect(&chatLog_, &IChatLog::itemUpdated, this, &ChatWidget::onMessageUpdated);
     connect(verticalScrollBar(), &QScrollBar::valueChanged, this, &ChatWidget::onScrollValueChanged);
+    connect(verticalScrollBar(), &QScrollBar::rangeChanged, this, &ChatWidget::onScrollRangeChanged);
 
     auto firstChatLogIdx =
         clampedAdd(chatLog_.getNextIdx(), -settings.getChatMaxWindowSize(), chatLog_);
@@ -324,15 +327,22 @@ void ChatWidget::layout(int start, int end, qreal width)
     if (chatLineStorage->empty())
         return;
 
+    const int storageSize = static_cast<int>(chatLineStorage->size());
+    if (start >= storageSize)
+        return;
+
     qreal h = 0.0;
 
     // Line at start-1 is considered to have the correct position. All following lines are
     // positioned in respect to this line.
-    if (start - 1 >= 0)
-        h = (*chatLineStorage)[start - 1]->sceneBoundingRect().bottom() + lineSpacing;
+    if (start - 1 >= 0) {
+        if (start - 1 < storageSize) {
+            h = (*chatLineStorage)[start - 1]->sceneBoundingRect().bottom() + lineSpacing;
+        }
+    }
 
-    start = std::clamp<int>(start, 0, chatLineStorage->size());
-    end = std::clamp<int>(end + 1, 0, chatLineStorage->size());
+    start = std::clamp<int>(start, 0, storageSize);
+    end = std::clamp<int>(end, 0, storageSize);
 
     for (int i = start; i < end; ++i) {
         ChatLine* l = (*chatLineStorage)[i].get();
@@ -496,8 +506,11 @@ qreal ChatWidget::useableWidth() const
 
 void ChatWidget::insertChatlines(std::map<ChatLogIdx, ChatLine::Ptr> chatLines)
 {
-    if (chatLines.empty())
+    if (chatLines.empty()) {
+        scrollMonitoringEnabled = true;
+        emit renderFinished();
         return;
+    }
 
     const bool allLinesAtEnd = !chatLineStorage->hasIndexedMessage()
                                || chatLines.begin()->first > chatLineStorage->lastIdx();
@@ -554,6 +567,7 @@ void ChatWidget::insertChatlines(std::map<ChatLogIdx, ChatLine::Ptr> chatLines)
         updateTypingNotification();
         updateMultiSelectionRect();
 
+        scrollMonitoringEnabled = true;
         emit renderFinished();
     } else {
         startResizeWorker();
@@ -567,17 +581,23 @@ bool ChatWidget::stickToBottom() const
 
 void ChatWidget::scrollToBottom()
 {
+    stbLocked = true;
     updateSceneRect();
     verticalScrollBar()->setValue(verticalScrollBar()->maximum());
 }
 
 void ChatWidget::startResizeWorker()
 {
-    if (chatLineStorage->empty())
+    if (chatLineStorage->empty()) {
+        scrollMonitoringEnabled = true;
+        emit renderFinished();
         return;
+    }
 
     // (re)start the worker
-    if (!workerTimer->isActive()) {
+    if (workerTimer->isActive()) {
+        workerTimer->stop();
+    } else {
         // these values must not be reevaluated while the worker is running
         workerStb = stickToBottom();
 
@@ -598,9 +618,8 @@ void ChatWidget::startResizeWorker()
         setScene(busyScene);
 
     workerLastIndex = 0;
+    layoutGeneration++;
     workerTimer->start();
-
-    verticalScrollBar()->hide();
 }
 
 void ChatWidget::mouseDoubleClickEvent(QMouseEvent* ev)
@@ -686,7 +705,14 @@ void ChatWidget::clear()
 {
     clearSelection();
 
-    const QVector<ChatLine::Ptr> savedLines;
+    if (workerTimer->isActive()) {
+        workerTimer->stop();
+        workerAnchorLine = ChatLine::Ptr();
+    }
+
+    setScene(scene);
+    scrollMonitoringEnabled = true;
+    renderCompletionFns.clear();
 
     for (auto it = chatLineStorage->begin(); it != chatLineStorage->end();) {
         if (!isActiveFileTransfer(*it)) {
@@ -698,9 +724,12 @@ void ChatWidget::clear()
     }
 
     visibleLines.clear();
+    stbLocked = true;
 
     checkVisibility();
     updateSceneRect();
+
+    emit renderFinished();
 }
 
 void ChatWidget::copySelectedText(bool toSelectionBuffer) const
@@ -986,7 +1015,7 @@ void ChatWidget::removeLines(ChatLogIdx begin, ChatLogIdx end)
     }
 
     begin = std::clamp<ChatLogIdx>(begin, chatLineStorage->firstIdx(), chatLineStorage->lastIdx());
-    end = std::clamp<ChatLogIdx>(end, chatLineStorage->firstIdx(), chatLineStorage->lastIdx()) + 1;
+    end = std::clamp<ChatLogIdx>(end, chatLineStorage->firstIdx(), chatLineStorage->lastIdx() + 1);
 
     // NOTE: Optimization potential if this find proves to be too expensive.
     // Batching all our erases into one call would be more efficient
@@ -1037,16 +1066,28 @@ void ChatWidget::onSelectionTimerTimeout()
 
 void ChatWidget::onWorkerTimeout()
 {
-    // Fairly arbitrary but
-    // large values will make the UI unresponsive
+    const uint32_t generation = layoutGeneration;
     const int stepSize = 50;
 
-    layout(workerLastIndex, workerLastIndex + stepSize, useableWidth());
-    workerLastIndex += stepSize;
+    for (int i = 0; i < stepSize; ++i) {
+        if (generation != layoutGeneration) {
+            workerTimer->stop();
+            return;
+        }
+
+        if (static_cast<size_t>(workerLastIndex) >= chatLineStorage->size()) {
+            break;
+        }
+
+        layout(workerLastIndex, workerLastIndex + 1, useableWidth());
+        workerLastIndex++;
+    }
 
     // done?
-    if (workerLastIndex >= chatLineStorage->size()) {
+    if (workerLastIndex >= chatLineStorage->size() || generation != layoutGeneration) {
         workerTimer->stop();
+        if (generation != layoutGeneration)
+            return;
 
         // switch back to the scene containing the chat messages
         setScene(scene);
@@ -1066,8 +1107,7 @@ void ChatWidget::onWorkerTimeout()
         // don't keep a Ptr to the anchor line
         workerAnchorLine = ChatLine::Ptr();
 
-        // hidden during busy screen
-        verticalScrollBar()->show();
+        scrollMonitoringEnabled = true;
 
         emit renderFinished();
     }
@@ -1094,6 +1134,16 @@ void ChatWidget::renderMessages(ChatLogIdx begin, ChatLogIdx end)
 {
     auto linesToRender = std::map<ChatLogIdx, ChatLine::Ptr>();
 
+    const ChatLogIdx nextIdx = chatLog.getNextIdx();
+    if (begin >= nextIdx) {
+        emit renderFinished();
+        return;
+    }
+
+    if (end > nextIdx) {
+        end = nextIdx;
+    }
+
     for (auto i = begin; i < end; ++i) {
         const bool alreadyRendered = chatLineStorage->contains(i);
         const bool prevIdxRendered = i != begin || chatLineStorage->contains(i - 1);
@@ -1127,6 +1177,7 @@ void ChatWidget::setRenderedWindowStart(ChatLogIdx begin)
 
     // If the window is already where we have no work to do
     if (currentStart == begin) {
+        scrollMonitoringEnabled = true;
         emit renderFinished();
         return;
     }
@@ -1187,6 +1238,8 @@ void ChatWidget::onRenderFinished()
 
 void ChatWidget::onScrollValueChanged(int value)
 {
+    stbLocked = (value == verticalScrollBar()->maximum());
+
     if (!chatLineStorage->hasIndexedMessage()) {
         // This could be a little better. On a cleared screen we should probably
         // be able to scroll, but this makes the rest of this function easier
@@ -1216,6 +1269,8 @@ void ChatWidget::onScrollValueChanged(int value)
 
             scrollMonitoringEnabled = false;
             setRenderedWindowStart(idx);
+        } else {
+            emit renderFinished();
         }
 
     } else if (value == verticalScrollBar()->maximum()) {
@@ -1233,16 +1288,25 @@ void ChatWidget::onScrollValueChanged(int value)
                 if (it != chatLineStorage->end()) {
                     updateSceneRect();
                     verticalScrollBar()->setValue((*it)->sceneBoundingRect().bottom() - bottomOffset);
-                    scrollMonitoringEnabled = true;
                 }
+                scrollMonitoringEnabled = true;
             });
 
             scrollMonitoringEnabled = false;
             setRenderedWindowEnd(idx);
+        } else {
+            emit renderFinished();
         }
     }
 }
 
+void ChatWidget::onScrollRangeChanged(int /*min*/, int max)
+{
+    if (stbLocked) {
+        verticalScrollBar()->setValue(max);
+    }
+}
+
 void ChatWidget::handleMultiClickEvent()
 {
     // Ignore single or double clicks
@@ -1287,11 +1351,18 @@ void ChatWidget::hideEvent(QHideEvent* event)
     // qTox, but that isn't a regression from previously released behavior.
 
     const std::size_t maxWindowSize = settings.getChatMaxWindowSize();
-    auto numLinesToRemove =
-        chatLineStorage->size() > maxWindowSize ? chatLineStorage->size() - maxWindowSize : 0;
 
-    if (numLinesToRemove > 0) {
-        removeLines(chatLineStorage->firstIdx(), chatLineStorage->firstIdx() + numLinesToRemove);
+    if (chatLineStorage->size() > maxWindowSize) {
+        while (chatLineStorage->size() > maxWindowSize) {
+            auto it = chatLineStorage->begin();
+            (*it)->removeFromScene();
+            chatLineStorage->erase(it);
+        }
+
+        if (chatLineStorage->hasIndexedMessage()) {
+            layout(0, chatLineStorage->size(), useableWidth());
+        }
+
         startResizeWorker();
     }
 }
@@ -1379,7 +1450,7 @@ void ChatWidget::renderItem(const ChatLogItem& item, bool hideName, bool coloriz
 {
     const auto& sender = item.getSender();
 
-    const bool isSelf = sender == core.getSelfPublicKey();
+    const bool isSelf = sender == idHandler.getSelfPublicKey();
 
     switch (item.getContentType()) {
     case ChatLogItem::ContentType::message: {
@@ -1418,7 +1489,6 @@ void ChatWidget::renderFile(QString displayName, ToxFile file, bool isSelf, QDat
                             ChatLine::Ptr& chatMessage)
 {
     if (!chatMessage) {
-        CoreFile* coreFile = core.getCoreFile();
         assert(coreFile);
         chatMessage = ChatMessage::createFileTransferMessage(displayName, *coreFile, file, isSelf,
                                                              timestamp, documentCache, settings,
@@ -1518,3 +1588,19 @@ void ChatWidget::jumpToIdx(ChatLogIdx idx)
         setRenderedWindowStart(clampedAdd(idx, -windowChunkSize, chatLog));
     }
 }
+
+ChatLogIdx ChatWidget::getRenderedStartIdx() const
+{
+    if (!chatLineStorage->hasIndexedMessage()) {
+        return ChatLogIdx(-1);
+    }
+    return chatLineStorage->firstIdx();
+}
+
+ChatLogIdx ChatWidget::getRenderedEndIdx() const
+{
+    if (!chatLineStorage->hasIndexedMessage()) {
+        return ChatLogIdx(-1);
+    }
+    return chatLineStorage->lastIdx();
+}
