@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2014-2019 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #include "filetransferwidget.h"
@@ -27,8 +27,6 @@
 #include <QVariantAnimation>
 
 #include <cassert>
-#include <cmath>
-
 
 // The leftButton is used to accept, pause, or resume a file transfer, as well as to open a
 // received file.
@@ -192,7 +190,7 @@ void FileTransferWidget::paintEvent(QPaintEvent* event)
     // Draw the widget background:
     painter.setClipRect(QRect(0, 0, width(), height()));
     painter.setBrush(QBrush(backgroundColor));
-    painter.drawRoundedRect(geometry(), r * ratio, r, Qt::RelativeSize);
+    painter.drawRoundedRect(rect(), r * ratio, r, Qt::RelativeSize);
 
     if (drawButtonAreaNeeded()) {
         // Draw the button background:
@@ -224,7 +222,7 @@ void FileTransferWidget::paintEvent(QPaintEvent* event)
         // Draw the right button:
         painter.setBrush(QBrush(buttonColor));
         painter.setClipRect(QRect(width() - buttonFieldWidth, 0, buttonFieldWidth, buttonFieldWidth));
-        painter.drawRoundedRect(geometry(), r * ratio, r, Qt::RelativeSize);
+        painter.drawRoundedRect(rect(), r * ratio, r, Qt::RelativeSize);
     }
 }
 
