@@ -1,7 +1,7 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2013 by Maxim Biro <nurupo.contributions@gmail.com>
  * Copyright © 2014-2019 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #include "core.h"
@@ -290,7 +290,7 @@ bool Core::checkConnection()
 {
     ASSERT_CORE_THREAD;
     auto selfConnection = tox_self_get_connection_status(tox.get());
-    const char* connectionName;
+    const char* connectionName = "unknown";
     bool toxConnected = false;
     switch (selfConnection) {
     case TOX_CONNECTION_NONE:
