@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2021 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #pragma once
@@ -22,6 +22,8 @@ public:
     virtual bool isFriend() const = 0;
     virtual bool isConference() const = 0;
     virtual bool isOnline() const = 0;
+    virtual void startCall() = 0;
+    virtual void stopCall() = 0;
     virtual bool widgetIsVisible() const = 0;
     virtual QString getNameItem() const = 0;
     virtual QDateTime getLastActivity() const = 0;
