@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2020 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #pragma once
@@ -40,4 +40,7 @@ public:
 
     virtual bool getConferenceAlwaysNotify() const = 0;
     virtual void setConferenceAlwaysNotify(bool newValue) = 0;
+
+    virtual bool getHidePostNullSuffix() const = 0;
+    virtual void setHidePostNullSuffix(bool newValue) = 0;
 };
