@@ -1,16 +1,16 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
- * Copyright © 2025 The TokTok team.
+ * Copyright © 2025-2026 The TokTok team.
  */
 
 #pragma once
 
-#include "src/widget/tool/abstractscreenshotgrabber.h"
+#include "src/widget/tool/abstractscreenshotgrabber.h" // IWYU pragma: keep
 
 #include <QVariantMap>
 
+#if QT_CONFIG(dbus)
 #include <memory>
 
-#if QT_CONFIG(dbus)
 /** @brief Grabs screenshot using org.freedesktop.portal.Screenshot.
  *
  * https://docs.flatpak.org/en/latest/portal-api-reference.html#gdbus-org.freedesktop.portal.Screenshot
