@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2014-2019 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #include "genericchatform.h"
@@ -137,8 +137,8 @@ GenericChatForm::GenericChatForm(const Core& core_, const Chat* chat, IChatLog&
     headWidget = new ChatFormHeader(settings, style);
     searchForm = new SearchForm(settings, style);
     dateInfo = new QLabel(this);
-    chatWidget = new ChatWidget(chatLog_, core, documentCache, smileyPack, settings, style,
-                                messageBoxManager, this);
+    chatWidget = new ChatWidget(chatLog_, core, core.getCoreFile(), documentCache, smileyPack,
+                                settings, style, messageBoxManager, this);
     searchForm->hide();
     dateInfo->setAlignment(Qt::AlignHCenter);
 
@@ -343,6 +343,7 @@ QDateTime GenericChatForm::getLatestTime() const
         case SystemMessageType::messageSendFailed:
         case SystemMessageType::selfJoinedConference:
         case SystemMessageType::selfLeftConference:
+        case SystemMessageType::userWentOffline:
             return false;
         }
 
