@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2014-2019 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #include "friendlistwidget.h"
@@ -214,7 +214,7 @@ void FriendListWidget::sortByMode()
         }
         cleanMainLayout();
 
-        const QLocale ql(settings.getTranslation());
+        const QLocale ql(settings.getTranslationInUse());
         const QDate today = QDate::currentDate();
 #define COMMENT "Category for sorting friends by activity"
         // clang-format off
