@@ -1,6 +1,6 @@
 /* SPDX-License-Identifier: GPL-3.0-or-later
  * Copyright © 2017-2019 by The qTox Project Contributors
- * Copyright © 2024-2025 The TokTok team.
+ * Copyright © 2024-2026 The TokTok team.
  */
 
 #include "src/chatlog/textformatter.h"
@@ -8,7 +8,6 @@
 #include <QString>
 #include <QtTest/QtTest>
 
-#include <ctime>
 #include <functional>
 
 #define PAIR_FORMAT(input, output) {QStringLiteral(input), QStringLiteral(output)}
@@ -260,6 +259,16 @@ const QVector<QPair<QString, QString>> URL_CASES{
         "[&quot;" MAKE_LINK("https://en.wikipedia.org/wiki/Seal_(East_Asia)") "&quot;]?"),
 };
 
+const QVector<StringPair> POST_NULL_HTML_CASE{
+    // Test case for HTML output (in chat log).
+    PAIR_FORMAT("Hello\x00\x00some garbage here", "Hello<font color=\"#228B22\">[...]</font>"),
+};
+
+const QVector<StringPair> POST_NULL_PLAIN_CASE{
+    // Test case for plain text output (in notifications).
+    PAIR_FORMAT("Hello\x00\x00some garbage here", "Hello[...]"),
+};
+
 #undef PAIR_FORMAT
 
 using MarkdownFunction = QString (*)(const QString&, bool);
@@ -285,14 +294,27 @@ void workCasesTest(MarkdownFunction applyMarkdown, const QVector<MarkdownToTags>
     for (const MarkdownToTags& mtt : markdownToTags) {
         for (const StringPair& data : testData) {
             const QString input = processInput != nullptr ? processInput(data.first, mtt) : data.first;
-            QString output = processOutput != nullptr ? processOutput(data.second, mtt, showSymbols)
-                                                      : data.second;
-            QString result = applyMarkdown(input, showSymbols);
+            const QString output =
+                processOutput != nullptr ? processOutput(data.second, mtt, showSymbols) : data.second;
+            const QString result = applyMarkdown(input, showSymbols);
             QVERIFY(output == result);
         }
     }
 }
 
+/*
+ * @brief Testing cases for TRIfA suffix.
+ * @param testData Test data - string pairs "Source message - Message after formatting"
+ * @param True if suffixes should be replaced by [...]
+ */
+void postNullCasesTest(const QVector<StringPair>& testData, bool html)
+{
+    for (const StringPair& data : testData) {
+        const QString result = TextFormatter::processPostNullSuffix(data.first, html);
+        QCOMPARE(data.second, result);
+    }
+}
+
 /**
  * @brief Testing cases where markdown must not to work
  * @param applyMarkdown Function which is used to apply markdown
@@ -307,7 +329,7 @@ void exceptionsTest(MarkdownFunction applyMarkdown, const QVector<MarkdownToTags
 {
     for (const MarkdownToTags& mtt : markdownToTags) {
         for (const QString& e : exceptions) {
-            QString processedException = e.arg(mtt.markdownSequence);
+            const QString processedException = e.arg(mtt.markdownSequence);
             QVERIFY(processedException == applyMarkdown(processedException, showSymbols));
         }
     }
@@ -322,7 +344,7 @@ void exceptionsTest(MarkdownFunction applyMarkdown, const QVector<MarkdownToTags
 void specialCasesTest(MarkdownFunction applyMarkdown, const QVector<StringPair>& pairs)
 {
     for (const auto& p : pairs) {
-        QString result = applyMarkdown(p.first, false);
+        const QString result = applyMarkdown(p.first, false);
         QVERIFY(p.second == result);
     }
 }
@@ -336,7 +358,7 @@ using UrlHighlightFunction = QString (*)(const QString&);
 void urlHighlightTest(UrlHighlightFunction function, const QVector<QPair<QString, QString>>& data)
 {
     for (const QPair<QString, QString>& p : data) {
-        QString result = function(p.first);
+        const QString result = function(p.first);
         QVERIFY(p.second == result);
     }
 }
@@ -409,6 +431,8 @@ private slots:
     void singleAndDoubleMarkdownExceptionsShowSymbols();
     void singleAndDoubleMarkdownExceptionsHideSymbols();
     void mixedFormattingSpecialCases();
+    void postNullTagsHtml();
+    void postNullTagsPlain();
     void urlTest();
 
 private:
@@ -506,5 +530,15 @@ void TestTextFormatter::urlTest()
     urlHighlightTest(urlHighlightFunction, URL_CASES);
 }
 
+void TestTextFormatter::postNullTagsHtml()
+{
+    postNullCasesTest(POST_NULL_HTML_CASE, true);
+}
+
+void TestTextFormatter::postNullTagsPlain()
+{
+    postNullCasesTest(POST_NULL_PLAIN_CASE, false);
+}
+
 QTEST_GUILESS_MAIN(TestTextFormatter)
 #include "textformatter_test.moc"
