@@ -1,6 +1,9 @@
+/* SPDX-License-Identifier: GPL-3.0-or-later
+ * Copyright © 2026 The TokTok team.
+ */
+
 #include "src/persistence/serialize.h"
 
-#include <cassert>
 #include <cstdlib>
 #include <cstring>
 
